%global pkgname edim

Name:           gap-pkg-%{pkgname}
Version:        1.3.2
Release:        2%{?dist}
Summary:        Elementary divisors of integer matrices

# doc/mathml.css is MPLv1.1; all other files are GPLv2+
License:        GPLv2+ and MPLv1.1
URL:            http://www.math.rwth-aachen.de/~Frank.Luebeck/EDIM/
Source0:        http://www.math.rwth-aachen.de/~Frank.Luebeck/EDIM/%{pkgname}-%{version}.tar.bz2

BuildRequires:  gap-devel

Requires:       gap-core
Requires(post): gap-core
Requires(postun): gap-core

%description
The main purpose of the EDIM package is to publish an implementation of
an algorithm (found by the package author) for computing prime parts of
the elementary divisors of integer matrices (i.e., the diagonal entries
of the Smith normal form).

The programs are developed and already successfully used for large
matrices (up to rank >12000) with moderate entries and many non-trivial
elementary divisors which are products of some small primes. But they
should be useful for other types of matrices as well.

Among the other functions of the package are:
- an inversion algorithm for large rational matrices (using a p-adic
  method)
- a program for finding the largest elementary divisor of an integral
  matrix (particularly interesting when this is much smaller than the
  determinant) and
- implementations of some normal form algorithms described by Havas,
  Majewski, Matthews, Sterling (using LLL- or modular techniques).

%prep
%setup -q -n %{pkgname}

# Fix encodings
for fil in doc/edim.bib doc/edim.bbl; do
  iconv -f iso8859-1 -t utf-8 $fil > $fil.utf8
  touch -r $fil $fil.utf8
  mv -f $fil.utf8 $fil
done

%build
# This is NOT an autoconf-generated script.  Do not use %%configure.
./configure %{_gap_dir}
make %{?_smp_mflags}
chmod 0755 bin/*/ediv.so

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../%{pkgname} %{buildroot}%{_gap_dir}/pkg
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{doc/clean,CHANGES,configure,GPL,Makefile*,README}
rm -fr %{buildroot}%{_gap_dir}/pkg/%{pkgname}/src

%post -p %{_bindir}/update-gap-workspace

%postun -p %{_bindir}/update-gap-workspace

%check
gap -l "%{_gap_dir};%{buildroot}%{_gap_dir}" < tst/test.g

%files
%doc CHANGES README
%license GPL
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%docdir %{_gap_dir}/pkg/%{pkgname}/htm
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed May 20 2015 Jerry James <loganjerry@gmail.com> - 1.3.2-1
- Initial RPM (bz 1223627)
